@@ -4,21 +4,23 @@
 #'concentrations as a result of infusion dosing.
 #'
 #'@param chem.name Either the chemical name, CAS number, or the parameters must 
-#'be specified.
+#' be specified.
 #'@param chem.cas Either the chemical name, CAS number, or the parameters must 
-#'be specified.
+#' be specified.
+#' @param dtxsid EPA's 'DSSTox Structure ID (\url{http://comptox.epa.gov/dashboard})  
+#' the chemical must be identified by either CAS, name, or DTXSIDs
 #'@param parameters Chemical parameters from parameterize_pbtk (for model = 
-#''pbtk'), parameterize_3comp (for model = '3compartment), 
-#'parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
-#'(for model = '3compartmentss'), overrides chem.name and chem.cas.
+#' 'pbtk'), parameterize_3comp (for model = '3compartment), 
+#' parmeterize_1comp(for model = '1compartment') or parameterize_steadystate 
+#' (for model = '3compartmentss'), overrides chem.name and chem.cas.
 #'@param hourly.dose Hourly dose rate mg/kg BW/h.
 #'@param concentration Desired concentration type, 'blood' or default 'plasma'.
 #'@param suppress.messages Whether or not the output message is suppressed.
 #'@param recalc.blood2plasma Recalculates the ratio of the amount of chemical 
-#'in the blood to plasma using the input parameters. Use this if you have 
-#''altered hematocrit, Funbound.plasma, or Krbc2pu.
+#' in the blood to plasma using the input parameters. Use this if you have 
+#' 'altered hematocrit, Funbound.plasma, or Krbc2pu.
 #'@param tissue Desired tissue conentration (defaults to whole body 
-#'concentration.)
+#' concentration.)
 #'@param restrictive.clearance If TRUE (default), then only the fraction of
 #' chemical not bound to protein is available for metabolism in the liver. If 
 #' FALSE, then all chemical in the liver is metabolized (faster metabolism due
@@ -27,13 +29,15 @@
 #' as bioactive in vivo. If TRUE, the the unbound (free) plasma concentration is treated as 
 #' bioactive in vivo. Only works with \code{tissue = NULL} in current implementation.
 #'@param ... Additional parameters passed to parameterize function if 
-#'parameters is NULL.
+#' parameters is NULL.
 #'  
 #'@return Steady state concentration in uM units
 #'
 #'@author Robert Pearce and John Wambaugh
+#'@keywords 3compartment
 calc_analytic_css_3comp <- function(chem.name=NULL,
                                    chem.cas = NULL,
+                                   dtxsid=NULL,
                                    parameters=NULL,
                                    hourly.dose=1/24,
                                    concentration='plasma',
@@ -52,12 +56,27 @@ calc_analytic_css_3comp <- function(chem.name=NULL,
   dose <- NULL
   #End R CMD CHECK appeasement.
   
-  if (is.null(chem.cas) & is.null(chem.name) & is.null(parameters))
-  {
-    stop('Parameters, chem.name, or chem.cas must be specified.')
-  }
+  param.names.3comp <- model.list[["3compartment"]]$param.names
+  param.names.schmitt <- model.list[["schmitt"]]$param.names
+    
+# We need to describe the chemical to be simulated one way or another:
+  if (is.null(chem.cas) & 
+      is.null(chem.name) & 
+      is.null(dtxsid) &
+      is.null(parameters)) 
+    stop('parameters, chem.name, chem.cas, or dtxsid must be specified.')
+
+# Look up the chemical name/CAS, depending on what was provide:
   if (is.null(parameters))
   {
+    out <- get_chem_id(
+            chem.cas=chem.cas,
+            chem.name=chem.name,
+            dtxsid=dtxsid)
+    chem.cas <- out$chem.cas
+    chem.name <- out$chem.name                                
+    dtxsid <- out$dtxsid  
+
     parameters <- parameterize_3comp(chem.cas=chem.cas,
                                     chem.name=chem.name,
                                     suppress.messages=suppress.messages,
@@ -74,6 +93,7 @@ calc_analytic_css_3comp <- function(chem.name=NULL,
              collapse=', '),
            ".  Use parameters from parameterize_3comp."))
     }
+    param.names.pbtk <- model.list[["pbtk"]]$param.names 
     if (any(param.names.pbtk[which(!param.names.pbtk %in% param.names.3comp)] 
       %in% names(parameters)))
     {
@@ -83,6 +103,8 @@ calc_analytic_css_3comp <- function(chem.name=NULL,
       parameters[['hematocrit']] + 
       parameters[['hematocrit']] * parameters[['Krbc2pu']] * parameters[['Funbound.plasma']]
   }
+  param.names.schmitt <- model.list[["schmitt"]]$param.names
+
 
   hourly.dose <- hourly.dose * parameters$Fgutabs
   fup <- parameters$Funbound.plasma
