@@ -296,28 +296,29 @@ calc_mc_css <- function(chem.cas=NULL,
 
   css.list <- parameter.dt$Css 
   
-  if (!suppress.messages & !return.samples)
+  if (!return.samples) out <- quantile(css.list,which.quantile,na.rm=T)  
+  else out <- css.list  
+
+  if (!suppress.messages)
   {
-    if (is.null(tissue)) cat(paste(toupper(substr(species,1,1)),
-      substr(species,2,nchar(species)),sep=''),
-      "plasma concentration returned in",
-      output.units,
-      "units for",
-      which.quantile,
-      "quantile.\n") 
-      else cat(paste(toupper(substr(species,1,1)),
+    if (!return.samples)
+    {
+      if (is.null(tissue)) cat(paste(toupper(substr(species,1,1)),
         substr(species,2,nchar(species)),sep=''),
-        tissue,
-        "concentration returned in",
+        "plasma concentration returned in",
         output.units,
         "units for",
         which.quantile,
         "quantile.\n") 
-    out <- quantile(css.list,which.quantile,na.rm=T)     
-  } else {
-    out <- css.list  
-    if (!suppress.messages) 
-    {
+        else cat(paste(toupper(substr(species,1,1)),
+          substr(species,2,nchar(species)),sep=''),
+          tissue,
+          "concentration returned in",
+          output.units,
+          "units for",
+          which.quantile,
+          "quantile.\n")    
+    } else {
       if (is.null(tissue)) cat(paste(toupper(substr(species,1,1)),
         substr(species,2,nchar(species)),sep=''),
         "plasma concentration returned in",
@@ -329,12 +330,11 @@ calc_mc_css <- function(chem.cas=NULL,
         "concentration returned in",
         output.units,
         "units.\n") 
-      out <- css.list
     }
   }
 
 # Cannot guarantee arbitrary precision:
-  out <- signif(out,4)
+  out <- set_httk_precision(out)
   
   return(out)
 }
