@@ -16,4 +16,16 @@ length(unique(chem.physical_and_invitro.data$Compound)) == dim(chem.physical_and
 length(unique(subset(chem.physical_and_invitro.data,!is.na(DTXSID))$DTXSID)) == 
   dim(subset(chem.physical_and_invitro.data,!is.na(DTXSID)))[1]
   
+# Check if the requirements for diffrent models has changed:
+length(get_cheminfo())
+length(get_cheminfo(species="rat"))
+length(get_cheminfo(model="pbtk"))
+length(get_cheminfo(model="pbtk",species="rat"))
+length(get_cheminfo(info="all"))
+length(get_cheminfo(model="schmitt"))
+length(get_cheminfo(model="schmitt",species="rat"))
+length(get_cheminfo(model="1compartment"))
+length(get_cheminfo(model="1compartment",species="rat"))
+  
+  
 quit("no")
\ No newline at end of file
